]> AND Private Git Repository - loba.git/blobdiff - process.h
Logo AND Algorithmique Numérique Distribuée

Private GIT Repository
Use a separate thread to handle incoming messages.
[loba.git] / process.h
index c30b24374e0aed763bb626ed6d087350b1dbc548..654237b8b9f77f2d1050f0d88a0760a097954ac8 100644 (file)
--- a/process.h
+++ b/process.h
 
 class process {
 public:
-    static double get_total_load_init() { return total_load_init; }
-    static double get_total_load_exit() { return total_load_exit; }
+    static double get_total_load_init()    { return total_load_init;    }
+    static double get_total_load_running() { return total_load_running; }
+    static double get_total_load_exit()    { return total_load_exit;    }
 
     process(int argc, char* argv[]);
     virtual ~process();
 
+    double get_load() const                { return load; }
+
     int run();
 
 protected:
@@ -48,8 +51,9 @@ protected:
                        xbt_log_category_t cat = _XBT_LOGV(default)) const;
 
 private:
-    static double total_load_init; // sum of neighbor loads at init
-    static double total_load_exit; // sum of neighbor loads at exit
+    static double total_load_init; // sum of process loads at init
+    static double total_load_running; // summ of loads while running
+    static double total_load_exit; // sum of process loads at exit
 
     typedef MAP_TEMPLATE<m_host_t, neighbor*> rev_neigh_type;
     neigh_type neigh;           // list of neighbors (do not alter
@@ -63,8 +67,10 @@ private:
                                 // on data channel
     bool close_received;        // true if we received a "close" message
     bool may_receive;           // true if there remains neighbors to listen for
+    bool finalizing;            // true when finalize() is running
 
-    unsigned iter;              // counter of iterations
+    unsigned lb_iter;           // counter of load-balancing iterations
+    unsigned comp_iter;         // counter of computation iterations
 
     double prev_load_broadcast; // used to ensure that we do not send
                                 // a same information messages